 
% Matlab routine for calculating Venn-Abers and Simplified Venn-Abers
% probabilities

% Ivan Petej
% University of Royal Holloway
% 2014

% paper reference: Venn-Abers Predictors (Vovk & Petej), proceedings of the
% UAI Conference 2014

% functions for calculating Venn-Abers (VA) Simplified Venn-Abers (SVA) or
% isotonic regression (Zadrozny-Elkan method abbreviated ZE) probabilities

% usage:

% outputs = genProbsVA(data,weka_algorithm);

% weka_algorithm is based on the Weka Data mining tool Weka 3.7.10 available for download
% http://www.cs.waikato.ac.nz/ml/weka/

% please note that functions require the Matlab-R interface available for download at
% http://www.mathworks.co.uk/matlabcentral/fileexchange/5051-matlab-r-link/

% and the Matlab-Weka interface available for download at:
% http://www.mathworks.co.uk/matlabcentral/fileexchange/21204-matlab-weka-interface%


% algorithms are:
% 'tree' - J48 Decision Tree
% 'SMO' - Platt SVM method
% 'naive' - Naive Nayes
% 'logistic' - Logistic Regression
% 'bagging' - J48 with Bagging
% 'nn' - Neural Networks


% data corresponds to choice of datasets (UCI repository, included) which are:

% 'australian'
% 'breast'
% 'diabetes'
% 'echo'
% 'hepatitis'
% 'ionosphere'
% 'labor'
% 'liver'
% 'vote'

% generated outputs are

% classProbsTrain - training set probabilites calculated using the Weka algorithm
% classProbsTest - test set probabilites calculated using the Weka algorithm
% actual - actual test set labels
% p0_p1 - p0 and p1 values calculated using the Venn Abers (VA) or Simplifed Venn Abers (SVA) technique
% probVABrier - Venn Abers Brier loss probabilities
% probVAlog - Venn Abers log loss probabilities 
% errWekaBrier - Brier loss for Weka algorithm
% errWekalog - log loss for Weka algorithm
% errVABrier - total Brier loss for Venn Abers predictor (equivalent for SVA or ZE)
% errVAlog - total log loss for Venn Abers predictor (equivalent for SVA or ZE)

% example

[classProbsTrain,classProbsTest, actual, p0_p1,probVABrier,probVAlog,errWekaBrier,errWekalog,errSVABrier,errSVAlog ] = genProbsSVA('echo','bagging');